@@ -1,4 +1,4 @@
-if [ ! -f /etc/irssi.conf ]
+if [ ! -e /etc/irssi.conf ]
 then
     /usr/bin/mkdir -p /etc
     /usr/bin/cp /etc/defaults/etc/irssi.conf /etc/irssi.conf
